==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/LastWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { LastWeekExpressionDescription } from "./LastWeekExpressionDescription";
/**
 * @hidden
 */
export let LastWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastWeekExpressionDescriptionMetadata.a == null) {
                LastWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastWeekExpressionDescriptionMetadata.c(LastWeekExpressionDescriptionMetadata.a);
            }
            if (a.j(LastWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(LastWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            OffsettableWeekExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastWeekExpressionDescriptionMetadata.b(a);
            a.aa("LastWeekExpression", () => new LastWeekExpressionDescription());
            a.z("LastWeekExpression", LastWeekExpressionDescriptionMetadata.a);
        }
    }
    LastWeekExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastWeekExpressionDescriptionMetadata, 'LastWeekExpressionDescriptionMetadata');
    LastWeekExpressionDescriptionMetadata.a = null;
    return LastWeekExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LastWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { LastWeekExpressionDescription } from "./LastWeekExpressionDescription";
/**
 * @hidden
 */
export let LastWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastWeekExpressionDescriptionMetadata.a == null) {
                LastWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastWeekExpressionDescriptionMetadata.c(LastWeekExpressionDescriptionMetadata.a);
            }
            if (a.k(LastWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(LastWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            OffsettableWeekExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastWeekExpressionDescriptionMetadata.b(a);
            a.ac("LastWeekExpression", () => new LastWeekExpressionDescription());
            a.ab("LastWeekExpression", LastWeekExpressionDescriptionMetadata.a);
        }
    }
    LastWeekExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastWeekExpressionDescriptionMetadata, 'LastWeekExpressionDescriptionMetadata');
    LastWeekExpressionDescriptionMetadata.a = null;
    return LastWeekExpressionDescriptionMetadata;
})();
